<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Bildbetrachter</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Version:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <source>images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>Alben</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Synchronisierung verwalten</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchronisiere:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Unbenannt</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Kürzlich importiert</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mein Favorit</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Sind Sie sicher, dass Sie dieses Album löschen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mein Favorit</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Zeitleiste</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Sie können Ordner der Timeline zum Synchronisieren hinzufügen oder auch einzelne Bilder per Drag &amp; Drop</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Unbenannt</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Deepin Bildbetrachter</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Sind Sie sicher, dass Sie die Bilder zu diesem Album hinzufügen möchten?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Erstellen und Synchronisieren</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Synchronisierung</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Sind Sie sicher, dass Sie die Auswahl zur Synchronisierungsliste hinzufügen möchten und ein Album mit dem Namen des Ordners erstellt werden soll?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Erfolgreich exportiert</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Export fehlgeschlagen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Sind Sie sicher, dass Sie Bilder in den PAPIERKORB werfen möchten?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Die Datei enthält mehrere Seiten. Verwenden Sie den Dokumentbetrachter Evince, um alle Seiten einzusehen.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Sie können Ordner der Timeline zum synchronisieren hinzufügen oder auch einzelne Bilder per Drag &amp; Drop</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Zu Album hinzufügen</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Zu neuem Album hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Sie haben keine Berechtigung das Bild zu betrachten</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Aufnahmedatum</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farbraum</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtungsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtungsprogramm</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtungszeit</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blitz</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Blende</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brennweite</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Maximale Blendenöffnung</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Messmethode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Weißabgleich</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blitzbelichtungskorrektur</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linsenmodell</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Keine Skalierung</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Seite an Bild anpassen</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Bild an Seite anpassen</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Skalieren auf:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeter</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Zentimeter</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Zoll</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Bildposition</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Skalierung</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Bildeigenschaften</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Jalousie</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Überdecken</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Wischen</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Oval</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Verzeichnis auswählen</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Dieser Ordner wird nicht synchronisiert</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Ordner hinzufügen</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Synchronisierungsverwaltung</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Die Verzeichnisliste ist leer</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Synchronisierung abbrechen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Das Gerät wurde entfernt</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Dieses Verzeichnis ist nicht länger vorhanden</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Berechnung läuft...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Bildbetrachtung</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diashow beenden</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Vorheriger Bildschirm</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Nächster Bildschirm</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkürzel anzeigen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Bitte geben Sie ein neues Tastenkürzel ein</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Bild anzeigen</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Standardeinstellungen wiederherstellen</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Diashow beenden</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Diashow beenden</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pause/Wiedergabe</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Präsentationseinstellungen</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Übergangseffekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Übergangsdauer</translation>
    </message>
    <message>
        <source>second</source>
        <translation>Sekunde</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Bildverwaltung</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mein Favorit</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Originalgröße</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Auf Fenstergröße anpassen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Keine Bilddateien gefunden</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 Bild</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 Bilder</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Synchronisierung verwalten</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Synchronisiere:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Sie können Ordner der Timeline zum synchronisieren hinzufügen oder auch einzelne Bilder per Drag &amp; Drop</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Zu Album hinzufügen</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Zu neuem Album hinzufügen</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Animationseinstellungen</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Effekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Dauer</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Tastenkürzel</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>tt MMMM jjjj</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Mein Favorit</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Kürzlich importiert</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>Deepin Image Viewer ist ein moderner &amp; leichter Bildbetrachter.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Es hat die Funktionen Bilderverwaltung, Bilder anzeigen und grundlegende Bildbearbeitung</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Dunkles Design</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>Der Deepin Bildbetrachter ist eine elegante &amp; schnelle Bildverwaltung.</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Zeitleiste</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Zu Album hinzufügen</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Zu neuem Album hinzufügen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>In Zwischenablage kopieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Als Favorit entfernen</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigationsfenster anzeigen</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigationsfenster ausblenden</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinformation</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle Bilder</translation>
    </message>
</context>
</TS>